@@ -3,6 +3,7 @@ from __future__ import absolute_import, division, unicode_literals
 import logging
 import logging.handlers
 import string
+import sys
 import threading
 import warnings
 
@@ -110,6 +111,9 @@ def start(filename=None, level=logging.INFO, to_console=True, to_file=True):
 
     # root logger
     logger = logging.getLogger()
+    if not isinstance(level, int):
+        # Python logging api is horrible. This is getting the level number, which is required on python 2.6.
+        level = logging.getLevelName(level)
     logger.setLevel(level)
 
     formatter = FlexGetFormatter()
@@ -120,7 +124,7 @@ def start(filename=None, level=logging.INFO, to_console=True, to_file=True):
 
     # without --cron we log to console
     if to_console:
-        console_handler = logging.StreamHandler()
+        console_handler = logging.StreamHandler(sys.stdout)
         console_handler.setFormatter(formatter)
         logger.addHandler(console_handler)
 
